<?php

namespace Drupal\Tests\debug_headers\Functional;

use Drupal\Tests\BrowserTestBase;
use Drupal\user\RoleInterface;

/**
 * Debug headers functional test class.
 */
class DebugHeadersBlockTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'debug_headers',
    'user',
    'block',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Test that the headers block shows headers in comments.
   */
  public function testAccessToDebugHeadersBlock() {

    $anonPerms = [
      'access content',
    ];
    user_role_grant_permissions(RoleInterface::ANONYMOUS_ID, $anonPerms);

    $this->drupalPlaceBlock('debug_headers', [
      'wrap_in_html_comments' => TRUE,
    ]);

    $this->drupalGet('');

    $this->assertSession()->responseNotContains('Headers List');
    $this->assertSession()->responseNotContains('host');
    $this->assertSession()->responseNotContains('user-agent');
    $this->assertSession()->responseNotContains('cookie');
    $this->assertSession()->responseNotContains('SIMPLETEST_USER_AGENT');
  }

  /**
   * Test that the headers block shows headers.
   */
  public function testTheHeadersBlockShowsHeaders() {

    $anonPerms = [
      'access content',
      'view debug headers block',
    ];
    user_role_grant_permissions(RoleInterface::ANONYMOUS_ID, $anonPerms);

    $this->drupalPlaceBlock('debug_headers', [
      'wrap_in_html_comments' => FALSE,
    ]);

    $this->drupalGet('');

    $this->assertSession()->pageTextContains('Headers List');
    $this->assertSession()->pageTextContains('host');
    $this->assertSession()->pageTextContains('user-agent');
    $this->assertSession()->pageTextContains('cookie');
    $this->assertSession()->pageTextContains('SIMPLETEST_USER_AGENT');
  }

  /**
   * Test that the headers block shows headers in comments.
   */
  public function testTheHeadersBlockShowsHeadersInComments() {

    $anonPerms = [
      'access content',
      'view debug headers block',
    ];
    user_role_grant_permissions(RoleInterface::ANONYMOUS_ID, $anonPerms);

    $this->drupalPlaceBlock('debug_headers', [
      'wrap_in_html_comments' => TRUE,
    ]);

    $this->drupalGet('');

    $this->assertSession()->responseContains('<!-- Headers List');
    $this->assertSession()->responseContains('host');
    $this->assertSession()->responseContains('user-agent');
    $this->assertSession()->responseContains('cookie');
    $this->assertSession()->responseContains('SIMPLETEST_USER_AGENT');
  }

}
